@@ -6,22 +6,28 @@ from .api import API
 from .bucket import Bucket
 from .config import Config
 from .logger import initialize_logger
-from .oidc import OIDC, is_worker_username
+from .oidc import OIDC
+from .pubsub import ProteusPubSub
 from .reporting import Reporting
 from .runs import Runs
+from .safe import Safely
+from .stats import RunExecutionStats
 from .vault import Vault
 
 
 class Proteus:
     def __init__(self, config: Config = None) -> None:
-        self.config = config or Config()
+        self.config: Config = config or Config()
         self.logger = initialize_logger(self.config.log_loc)
-        self.auth = OIDC(self)
         self.api = API(self)
+        self.auth = OIDC(self)
         self.reporting = Reporting(self)
-        self.runs = Runs(self)
+        self.run_stats = RunExecutionStats(self)
         self.vault = Vault(self)
         self.bucket = Bucket(self)
+        self.runs = Runs(self)
+        self.safely = Safely(self)
+        self.pubsub = ProteusPubSub(self)
 
     def runs_authentified(self, func=None, user=None, password=None):
         """Decorator that authentifies and keeps token updated during execution."""
@@ -34,10 +40,7 @@ class Proteus:
 
             def __enter__(self):
                 terms = dict(username=self.ctx_user, password=self.ctx_password, auto_update=True)
-                is_worker = is_worker_username(self.ctx_user)
-                authentified = (
-                    self.runtime.auth.do_worker_login(**terms) if is_worker else self.runtime.auth.do_login(**terms)
-                )
+                authentified = self.runtime.auth.do_login(**terms)
                 if not authentified:
                     self.runtime.logger.error("Authentication failure, exiting")
                     sys.exit(1)
@@ -50,8 +53,8 @@ class Proteus:
         if not func:
             return RunsAuthentifiedContextManager(runtime=self, ctx_user=user, ctx_password=password)
 
-        wrapped_user = user
-        wrapped_password = password
+        wrapped_user = user or self.config.username
+        wrapped_password = password or self.config.password
 
         @wraps(func)
         def wrapper(user=wrapped_user, password=wrapped_password, *fn_args, **fn_kwargs):
