@@ -1,6 +1,7 @@
 import json
 import os
 import shutil
+import typing
 import uuid
 from copy import copy
 from pathlib import Path
@@ -14,15 +15,23 @@ from requests import Response, HTTPError, JSONDecodeError
 
 from proteus.bucket import AZ_COPY_PRESENT, AzCopyError
 
+if typing.TYPE_CHECKING:
+    from . import Proteus
+
 
 class API:
     CONTENT_CHUNK_SIZE = 10 * 1024 * 1024
 
-    def __init__(self, proteus):
+    def __init__(self, proteus: "Proteus"):
         self.proteus = proteus
         self.host = proteus.config.api_host
         self.host_v2 = proteus.config.api_host_v2
 
+        if not self.proteus.config.ssl_verify:
+            import urllib3
+
+            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
+
     def get(self, *args, **kwargs):
         return self._get_head("get", *args, **kwargs)
 
@@ -79,7 +88,6 @@ class API:
         url = self.build_url(url)
 
         headers = {
-            "Authorization": f"Bearer {self.proteus.auth.access_token}",
             "Content-Type": "application/json",
             **dict(headers),
         }
@@ -94,9 +102,13 @@ class API:
             composed_params["timeout"] = (timeout, None)
 
         def _do_request():
-            res = requests.request(method, url, **composed_params)
-            self.raise_for_status(res)
-            return res
+            def request_fn():
+                composed_params["headers"]["Authorization"] = f"Bearer {self.proteus.auth.access_token}"
+                return requests.request(method, url, **composed_params)
+
+            res = request_fn()
+            retried_res = self.raise_for_status(res, retry_refresh_fn=request_fn)
+            return retried_res or res
 
         return self._retry(_do_request, retry, retry_delay)
 
@@ -202,12 +214,6 @@ class API:
             {"file": {"ready": True}},
         )
 
-        try:
-            self.raise_for_status(response)
-        except Exception as error:
-            self.proteus.logger.error(response.content)
-            raise error
-
         # Patch the file to the original response
         original_response_json = original_response.json()
         original_response_json["file"] = response.json()["file"]
@@ -250,9 +256,10 @@ class API:
         if localname is not None:
             local = os.path.join(local, localname)
 
-        if False and self.proteus.bucket.is_proteus_bucket_file_url(url):
+        if self.proteus.bucket.is_proteus_bucket_file_url(url):
             try:
-                with TemporaryDirectory(dir=os.path.dirname(local), suffix="." + os.path.basename(local)) as tmpdir:
+                with TemporaryDirectory(suffix="." + os.path.basename(local)) as tmpdir:
+                    tmpdir = os.path.join(tmpdir, os.path.dirname(local))
                     download_path = list(self.proteus.bucket.download(url, tmpdir))[0]
                     shutil.move(download_path, local)
 
@@ -324,7 +331,7 @@ class API:
 
         return url
 
-    def raise_for_status(self, response: Response):
+    def raise_for_status(self, response: Response, retry_refresh_fn=None):
         try:
             response.raise_for_status()
         except HTTPError as http_error:
@@ -334,6 +341,23 @@ class API:
                     http_error.args = (
                         f"{http_error.args[0]}. Returned error " f"payload: {json.dumps(error_detail, indent=2)}",
                     )
+
+                message = error_detail.get("message", error_detail.get("msg", None))
+                do_retry_with_new_token = (
+                    retry_refresh_fn
+                    and isinstance(error_detail, dict)
+                    and message == "Expired token provided, please refresh"
+                )
+
+                if do_retry_with_new_token:
+                    self.proteus.auth.do_refresh()
+                    retry_res = retry_refresh_fn()
+                    self.raise_for_status(retry_res)
+                    return retry_res
+
             except JSONDecodeError:
                 pass
+
             raise http_error
+
+        return None
