@@ -34,14 +34,18 @@ class ProteusBucketFileUrl:
         self.info = None
         url_path = urlparse(url).path
         url_parts = self.BUCKET_FILE_V1_REGEX.match(url)
-        if url_parts:
-            self.url_path = url_path
-            self.bucket_id = url_parts.group("bucket_id")
-            self.filepath_or_uuid = url_parts.group("filepath_or_uuid")
-            try:
-                self.uuid = UUID(self.filepath_or_uuid)
-            except ValueError:
-                self.filepath = self.filepath_or_uuid
+
+        self.url_path = url_path
+
+        self.bucket_id = url_parts.group("bucket_id") if url_parts else None
+        self.filepath_or_uuid = url_parts.group("filepath_or_uuid") if url_parts else None
+
+        try:
+            self.uuid = UUID(self.filepath_or_uuid) if url_parts else None
+            self.filepath = None
+        except ValueError:
+            self.filepath = self.filepath_or_uuid
+            self.uuid = None
 
     def sync(self, timeout=60, retry=None, retry_delay=None):
         if self.info is None:
@@ -186,8 +190,18 @@ class Bucket:
 
     @contextmanager
     def _download_via_azcopy_tmp_folder(self, target_folder):
-        with TemporaryDirectory(prefix="_azcopy", dir=target_folder) as tmpdir:
-            yield tmpdir
+        if os.path.isabs(target_folder):
+            with TemporaryDirectory(prefix="_azcopy", dir=target_folder) as tmpdir:
+                yield tmpdir
+        else:
+            with TemporaryDirectory(prefix="_azcopy") as tmpdir:
+                yield tmpdir
+
+        try:
+            shutil.rmtree(tmpdir)
+        except FileNotFoundError as e:
+            if f"'{tmpdir}'" not in str(e):
+                raise
 
     def download_via_azcopy(self, bucket_uuid_or_file_url, target_folder, workers=8, replace=False, **search):
         try:
